==> react-bootstrap-table2-paginator-2.1.2.tgz: react-bootstrap-table2-paginator/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-table2-paginator`

# Summary
This package contains type definitions for react-bootstrap-table2-paginator (https://github.com/react-bootstrap-table/react-bootstrap-table2#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-table2-paginator.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-table2-paginator/index.d.ts)
````ts
// Type definitions for react-bootstrap-table2-paginator 2.1
// Project: https://github.com/react-bootstrap-table/react-bootstrap-table2#readme
// Definitions by: Wlad Meixner <https://github.com/gosticks>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.0

// documentation taken from https://react-bootstrap-table.github.io/react-bootstrap-table2/docs/table-props.html

import { PaginationOptions, BootstrapTableProps } from 'react-bootstrap-table-next';

export interface PaginationCtxOptions {
    options?: PaginationOptions | undefined;
}

/**
 * declaration for table pagination sub module and factory
 */
declare function paginationFactory(options: PaginationOptions): PaginationCtxOptions;

export default paginationFactory;

interface PaginationChildProps extends PaginationOptions {
    tableId?: string | undefined;
    bootstrap4?: boolean | undefined;
}

/**
 * Pagination context provider
 */
export function PaginationProvider(props: {
    pagination?: PaginationCtxOptions | undefined;
    children: (childProps: {
        paginationProps: PaginationChildProps;
        paginationTableProps: BootstrapTableProps;
    }) => React.ReactElement | null;
}): React.ReactElement | null;

export const PaginationTotalStandalone: React.FC<PaginationChildProps>;
export const PaginationListStandalone: React.FC<PaginationChildProps>;

export interface SizePerPageDropdownStandaloneProps extends PaginationChildProps {
    open?: boolean | undefined;
    hidden?: boolean | undefined;
    btnContextual?: boolean | undefined;
    variation?: 'dropdown' | 'dropup' | undefined;
    className?: string | undefined;
}

export const SizePerPageDropdownStandalone: React.FC<SizePerPageDropdownStandaloneProps>;

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 20:20:28 GMT
 * Dependencies: [@types/react-bootstrap-table-next](https://npmjs.com/package/@types/react-bootstrap-table-next)
 * Global values: none

# Credits
These definitions were written by [Wlad Meixner](https://github.com/gosticks).

==> react-bootstrap-table2-paginator-2.1.3.tgz: react-bootstrap-table2-paginator/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-table2-paginator`

# Summary
This package contains type definitions for react-bootstrap-table2-paginator (https://github.com/react-bootstrap-table/react-bootstrap-table2#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-table2-paginator.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-table2-paginator/index.d.ts)
````ts
// Type definitions for react-bootstrap-table2-paginator 2.1
// Project: https://github.com/react-bootstrap-table/react-bootstrap-table2#readme
// Definitions by: Wlad Meixner <https://github.com/gosticks>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.0

// documentation taken from https://react-bootstrap-table.github.io/react-bootstrap-table2/docs/table-props.html

import { BootstrapTableProps, PaginationOptions } from "react-bootstrap-table-next";

export interface PaginationCtxOptions {
    options?: PaginationOptions | undefined;
}

/**
 * declaration for table pagination sub module and factory
 */
declare function paginationFactory(options: PaginationOptions): PaginationCtxOptions;

export default paginationFactory;

interface PaginationChildProps extends PaginationOptions {
    tableId?: string | undefined;
    bootstrap4?: boolean | undefined;
}

/**
 * Pagination context provider
 */
export function PaginationProvider(props: {
    pagination?: PaginationCtxOptions | undefined;
    children: (childProps: {
        paginationProps: PaginationChildProps;
        paginationTableProps: BootstrapTableProps;
    }) => React.ReactElement | null;
}): React.ReactElement | null;

export const PaginationTotalStandalone: React.FC<PaginationChildProps>;
export const PaginationListStandalone: React.FC<PaginationChildProps>;

export interface SizePerPageDropdownStandaloneProps extends PaginationChildProps {
    open?: boolean | undefined;
    hidden?: boolean | undefined;
    btnContextual?: boolean | undefined;
    variation?: "dropdown" | "dropup" | undefined;
    className?: string | undefined;
}

export const SizePerPageDropdownStandalone: React.FC<SizePerPageDropdownStandaloneProps>;

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/react-bootstrap-table-next](https://npmjs.com/package/@types/react-bootstrap-table-next)
 * Global values: none

# Credits
These definitions were written by [Wlad Meixner](https://github.com/gosticks).
